@@ -432,10 +432,25 @@ class AerBackend(_AerBaseBackend):
         else:
             self._noise_model = noise_model
             characterisation = _process_model(noise_model, self._backend_info.gate_set)
+            averaged_errors = get_avg_characterisation(characterisation)
+
+            arch = characterisation["Architecture"]
+            self._backend_info.architecture = arch
+            self._backend_info.all_node_gate_errors = characterisation["NodeErrors"]
+            self._backend_info.all_edge_gate_errors = characterisation["EdgeErrors"]
+            self._backend_info.all_readout_errors = characterisation["ReadoutErrors"]
+
+            self._backend_info.averaged_node_gate_errors = averaged_errors[
+                "node_errors"
+            ]
+            self._backend_info.averaged_edge_gate_errors = averaged_errors[
+                "edge_errors"
+            ]
+            self._backend_info.averaged_readout_errors = averaged_errors[
+                "readout_errors"
+            ]
+
             characterisation_keys = [
-                "NodeErrors",
-                "EdgeErrors",
-                "ReadoutErrors",
                 "GenericOneQubitQErrors",
                 "GenericTwoQubitQErrors",
             ]
@@ -444,9 +459,8 @@ class AerBackend(_AerBaseBackend):
             characterisation = {
                 k: v for k, v in characterisation.items() if k in characterisation_keys
             }
-
-            self._backend_info.architecture = arch
             self._backend_info.misc["characterisation"] = characterisation
+
         self._memory = True
 
         self._backend.set_options(method=simulation_method)
@@ -490,7 +504,10 @@ class AerBackend(_AerBaseBackend):
                 CXMappingPass(
                     arch,
                     NoiseAwarePlacement(
-                        arch, **get_avg_characterisation(self.characterisation)
+                        arch,
+                        self._backend_info.averaged_node_gate_errors,
+                        self._backend_info.averaged_edge_gate_errors,
+                        self._backend_info.averaged_readout_errors,
                     ),
                     directed_cx=True,
                     delay_measures=False,
@@ -708,7 +725,7 @@ def _process_model(noise_model: NoiseModel, gate_set: Set[OpType]) -> dict:
             coupling_map.append(qubits)
 
     # free qubits (ie qubits with no link errors) have full connectivity
-    free_qubits = set(node_errors) - link_errors_qubits
+    free_qubits = set(node_errors).union(set(readout_errors)) - link_errors_qubits
 
     for q in free_qubits:
         for lq in link_errors_qubits:
