@@ -37,6 +37,7 @@ from qiskit.providers.ibmq.exceptions import IBMQBackendApiError  # type: ignore
 from qiskit.providers.ibmq.job import IBMQJob  # type: ignore
 from qiskit.result import Result, models  # type: ignore
 from qiskit.tools.monitor import job_monitor  # type: ignore
+from qiskit.providers.ibmq.utils.utils import api_status_to_job_status  # type: ignore
 
 from pytket.circuit import Circuit, OpType  # type: ignore
 from pytket.backends import Backend, CircuitNotRunError, CircuitStatus, ResultHandle
@@ -276,22 +277,23 @@ class IBMQBackend(Backend):
                 raise err
         else:
             provider = account_provider
-        self._backend: "_QiskIBMQBackend" = provider.get_backend(backend_name)
+        self._provider = provider
+        self._backend: "_QiskIBMQBackend" = self._provider.get_backend(backend_name)
         self._config = self._backend.configuration()
         self._max_per_job = getattr(self._config, "max_experiments", 1)
 
         # gather and store device specifics in BackendInfo
         characterisation = process_characterisation(self._backend)
+        averaged_errors = get_avg_characterisation(characterisation)
         characterisation_keys = [
-            "NodeErrors",
-            "EdgeErrors",
-            "ReadoutErrors",
-            "GenericOneQubitQErrors",
-            "GenericTwoQubitQErrors",
+            "t1times",
+            "t2times",
+            "Frequencies",
+            "GateTimes",
         ]
         arch = characterisation["Architecture"]
         # filter entries to keep
-        characterisation = {
+        filtered_characterisation = {
             k: v for k, v in characterisation.items() if k in characterisation_keys
         }
         supports_mid_measure = self._config.simulator or self._config.multi_meas_enabled
@@ -308,7 +310,13 @@ class IBMQBackend(Backend):
             gate_set,
             supports_midcircuit_measurement=supports_mid_measure,
             supports_fast_feedforward=supports_fast_feedforward,
-            misc={"characterisation": characterisation},
+            all_node_gate_errors=characterisation["NodeErrors"],
+            all_edge_gate_errors=characterisation["EdgeErrors"],
+            all_readout_errors=characterisation["ReadoutErrors"],
+            averaged_node_gate_errors=averaged_errors["node_errors"],
+            averaged_edge_gate_errors=averaged_errors["edge_errors"],
+            averaged_readout_errors=averaged_errors["readout_errors"],
+            misc={"characterisation": filtered_characterisation},
         )
 
         self._legacy_gateset = OpType.SX not in gate_set
@@ -377,7 +385,10 @@ class IBMQBackend(Backend):
             CXMappingPass(
                 arch,
                 NoiseAwarePlacement(
-                    arch, **get_avg_characterisation(self.characterisation)
+                    arch,
+                    self._backend_info.averaged_node_gate_errors,
+                    self._backend_info.averaged_edge_gate_errors,
+                    self._backend_info.averaged_readout_errors,
                 ),
                 directed_cx=False,
                 delay_measures=(not mid_measure),
@@ -486,7 +497,9 @@ class IBMQBackend(Backend):
 
     def circuit_status(self, handle: ResultHandle) -> CircuitStatus:
         self._check_handle_type(handle)
-        ibmstatus = self._retrieve_job(cast(str, handle[0])).status()
+        jobid = cast(str, handle[0])
+        apistatus = self._provider._api_client.job_status(jobid)["status"]
+        ibmstatus = api_status_to_job_status(apistatus)
         return CircuitStatus(_STATUS_MAP[ibmstatus], ibmstatus.value)
 
     def get_result(self, handle: ResultHandle, **kwargs: KwargTypes) -> BackendResult:
